==> haskell-network-uri-2.6.0.3-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-network-uri/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.0.3
id: network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
key: netwo_B6cnyX3vwvIANPyGOhBaPA
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation inteface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network.URI
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/network-uri-2.6.0.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/network-uri-2.6.0.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/network-uri-2.6.0.3
hs-libraries: HSnetwork-uri-2.6.0.3-B6cnyX3vwvIANPyGOhBaPA
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-uri-2.6.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-network-uri/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
key: netwo_DarCcUHK1BCJHlIYOjXe67
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network.URI
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/network-uri-2.6.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-DarCcUHK1BCJHlIYOjXe67
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
